==> nest-infrastructure-spring-boot-3.5.3.0-20251216.073107-14-sources.jar: com/digiwin/dap/nest/infrastructure/spring/boot/core/DwSpringApplicationRunListener.java <==
package com.digiwin.dap.nest.infrastructure.spring.boot.core;

import com.digiwin.dap.nest.kernel.core.util.JaSpiUtil;
import com.digiwin.dap.nest.infrastructure.spring.boot.util.DwSpringBootUtil;
import com.digiwin.dap.nest.infrastructure.spring.util.DwSpringCloudFix;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.SpringApplicationRunListener;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.Ordered;

import java.util.Objects;

/**
 * 注意高低版本spring-boot兼容
 *
 * @author chenjian
 * @since 2024年04月21日 18:59:42
 */
public class DwSpringApplicationRunListener implements SpringApplicationRunListener, Ordered {

    public DwSpringApplicationRunListener(SpringApplication springApplication, String[] args) {
        if (!DwSpringCloudFix.isCloudContainer()) {
            DwSpringBootUtil.setSpringApplication(springApplication);
            DwSpringBootUtil.setArgs(args);
            JaSpiUtil.getCustomBasePackageSet().addAll(Objects.requireNonNull(DwSpringBootUtil.initRootPackageSet()));
//        JaLogback.addFilter(JaLogbackFilter.class);
        }
    }

    @Override
    public void contextPrepared(ConfigurableApplicationContext context) {

    }

    @Override
    public void contextLoaded(ConfigurableApplicationContext context) {

    }

    @Override
    public void failed(ConfigurableApplicationContext context, Throwable exception) {
    }

    @Override
    public int getOrder() {
        return -10;
    }

}

==> nest-infrastructure-spring-boot-5.5.0.1000-20251217.080719-4-sources.jar: com/digiwin/dap/nest/infrastructure/spring/boot/core/DwSpringApplicationRunListener.java <==
package com.digiwin.dap.nest.infrastructure.spring.boot.core;

import com.digiwin.dap.nest.kernel.core.util.DwSpiUtil;
import com.digiwin.dap.nest.infrastructure.spring.boot.util.DwSpringBootUtil;
import com.digiwin.dap.nest.infrastructure.spring.util.DwSpringCloudFix;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.SpringApplicationRunListener;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.Ordered;

import java.util.Objects;

/**
 * 注意高低版本spring-boot兼容
 *
 * @author chenjian
 * @since 2024年04月21日 18:59:42
 */
public class DwSpringApplicationRunListener implements SpringApplicationRunListener, Ordered {

    public DwSpringApplicationRunListener(SpringApplication springApplication, String[] args) {
        if (!DwSpringCloudFix.isCloudContainer()) {
            DwSpringBootUtil.setSpringApplication(springApplication);
            DwSpringBootUtil.setArgs(args);
            DwSpiUtil.getCustomBasePackageSet().addAll(Objects.requireNonNull(DwSpringBootUtil.initRootPackageSet()));
//        JaLogback.addFilter(JaLogbackFilter.class);
        }
    }

    @Override
    public void contextPrepared(ConfigurableApplicationContext context) {

    }

    @Override
    public void contextLoaded(ConfigurableApplicationContext context) {

    }

    @Override
    public void failed(ConfigurableApplicationContext context, Throwable exception) {
    }

    @Override
    public int getOrder() {
        return -10;
    }

}
